@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -203,7 +199,6 @@ public class LocaleNames_be extends OpenListResourceBundle {
             { "FO", "\u0424\u0430\u0440\u044d\u0440\u0441\u043a\u0456\u044f \u0430\u0441\u0442\u0440\u0430\u0432\u044b" },
             { "Taml", "\u0442\u0430\u043c\u0456\u043b\u044c\u0441\u043a\u0430\u0435" },
             { "FR", "\u0424\u0440\u0430\u043d\u0446\u044b\u044f" },
-            { "root", "\u043a\u043e\u0440\u0430\u043d\u044c" },
             { "grc", "\u0441\u0442\u0430\u0440\u0430\u0436\u044b\u0442\u043d\u0430\u0433\u0440\u044d\u0447\u0430\u0441\u043a\u0430\u044f" },
             { "GA", "\u0413\u0430\u0431\u043e\u043d" },
             { "GB", "\u0412\u044f\u043b\u0456\u043a\u0430\u0431\u0440\u044b\u0442\u0430\u043d\u0456\u044f" },
@@ -490,7 +485,7 @@ public class LocaleNames_be extends OpenListResourceBundle {
             { "wal", "\u0432\u043e\u043b\u0430\u0439\u0442\u0430" },
             { "XA", "\u041f\u0441\u0435\u045e\u0434\u0430\u0430\u043a\u0446\u044d\u043d\u0442\u044b" },
             { "war", "\u0432\u0430\u0440\u0430\u0439" },
-            { "XB", "\u041f\u0441\u0435\u045e\u0434\u0430-Bidi" },
+            { "XB", "\u043f\u0441\u0435\u045e\u0434\u0430\u0434\u0432\u0443\u0445\u043d\u0430\u043f\u0440\u0430\u043c\u043a\u0430\u0432\u044b" },
             { "awa", "\u0430\u0432\u0430\u0434\u0445\u0456" },
             { "061", "\u041f\u0430\u043b\u0456\u043d\u0435\u0437\u0456\u044f" },
             { "XK", "\u041a\u043e\u0441\u0430\u0432\u0430" },
